==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserGetSingletonAllOfEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserBlock;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The embedded resources related to the object if the &#x60;expand&#x60; query parameter is specified
 */
@ApiModel(description = "The embedded resources related to the object if the `expand` query parameter is specified")
@JsonPropertyOrder({ UserGetSingletonAllOfEmbedded.JSON_PROPERTY_BLOCKS })
@JsonTypeName("UserGetSingleton_allOf__embedded")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserGetSingletonAllOfEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BLOCKS = "blocks";
    private List<UserBlock> blocks = null;

    public UserGetSingletonAllOfEmbedded() {
    }

    public UserGetSingletonAllOfEmbedded blocks(List<UserBlock> blocks) {

        this.blocks = blocks;
        return this;
    }

    public UserGetSingletonAllOfEmbedded addblocksItem(UserBlock blocksItem) {
        if (this.blocks == null) {
            this.blocks = new ArrayList<>();
        }
        this.blocks.add(blocksItem);
        return this;
    }

    /**
     * A list of access block details for the User account
     *
     * @return blocks
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of access block details for the User account")
    @JsonProperty(JSON_PROPERTY_BLOCKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserBlock> getBlocks() {
        return blocks;
    }

    @JsonProperty(JSON_PROPERTY_BLOCKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBlocks(List<UserBlock> blocks) {
        this.blocks = blocks;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserGetSingletonAllOfEmbedded userGetSingletonAllOfEmbedded = (UserGetSingletonAllOfEmbedded) o;
        return Objects.equals(this.blocks, userGetSingletonAllOfEmbedded.blocks);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(blocks);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserGetSingletonAllOfEmbedded {\n");
        sb.append("    blocks: ").append(toIndentedString(blocks)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserGetSingletonAllOfEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserBlock;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The embedded resources related to the object if the &#x60;expand&#x60; query parameter is specified
 */
@ApiModel(description = "The embedded resources related to the object if the `expand` query parameter is specified")
@JsonPropertyOrder({ UserGetSingletonAllOfEmbedded.JSON_PROPERTY_BLOCKS })
@JsonTypeName("UserGetSingleton_allOf__embedded")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserGetSingletonAllOfEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BLOCKS = "blocks";
    private List<UserBlock> blocks = null;

    public UserGetSingletonAllOfEmbedded() {
    }

    public UserGetSingletonAllOfEmbedded blocks(List<UserBlock> blocks) {

        this.blocks = blocks;
        return this;
    }

    public UserGetSingletonAllOfEmbedded addblocksItem(UserBlock blocksItem) {
        if (this.blocks == null) {
            this.blocks = new ArrayList<>();
        }
        this.blocks.add(blocksItem);
        return this;
    }

    /**
     * A list of access block details for the User account
     *
     * @return blocks
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of access block details for the User account")
    @JsonProperty(JSON_PROPERTY_BLOCKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserBlock> getBlocks() {
        return blocks;
    }

    @JsonProperty(JSON_PROPERTY_BLOCKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBlocks(List<UserBlock> blocks) {
        this.blocks = blocks;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserGetSingletonAllOfEmbedded userGetSingletonAllOfEmbedded = (UserGetSingletonAllOfEmbedded) o;
        return Objects.equals(this.blocks, userGetSingletonAllOfEmbedded.blocks);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(blocks);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserGetSingletonAllOfEmbedded {\n");
        sb.append("    blocks: ").append(toIndentedString(blocks)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
